==> istio-model-v1alpha3-6.8.1-sources.jar: io/fabric8/istio/api/networking/v1alpha3/LoadBalancerSettingsConsistentHashLBUseSourceIpFluent.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class LoadBalancerSettingsConsistentHashLBUseSourceIpFluent<A extends LoadBalancerSettingsConsistentHashLBUseSourceIpFluent<A>> extends BaseFluent<A>{
  public LoadBalancerSettingsConsistentHashLBUseSourceIpFluent() {
  }
  public LoadBalancerSettingsConsistentHashLBUseSourceIpFluent(LoadBalancerSettingsConsistentHashLBUseSourceIp instance) {
    instance = (instance != null ? instance : new LoadBalancerSettingsConsistentHashLBUseSourceIp());

    if (instance != null) {
      this.withUseSourceIp(instance.getUseSourceIp());
      this.withUseSourceIp(instance.getUseSourceIp());
    }
  }
  private Boolean useSourceIp;
  public Boolean getUseSourceIp() {
    return this.useSourceIp;
  }
  public A withUseSourceIp(Boolean useSourceIp) {
    this.useSourceIp=useSourceIp; return (A) this;
  }
  public boolean hasUseSourceIp() {
    return this.useSourceIp != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    LoadBalancerSettingsConsistentHashLBUseSourceIpFluent that = (LoadBalancerSettingsConsistentHashLBUseSourceIpFluent) o;
    if (!java.util.Objects.equals(useSourceIp, that.useSourceIp)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(useSourceIp,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (useSourceIp != null) { sb.append("useSourceIp:"); sb.append(useSourceIp); }
    sb.append("}");
    return sb.toString();
  }
  public A withUseSourceIp() {
    return withUseSourceIp(true);
  }
  
}

==> istio-model-v1alpha3-6.9.0-sources.jar: io/fabric8/istio/api/networking/v1alpha3/LoadBalancerSettingsConsistentHashLBUseSourceIpFluent.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class LoadBalancerSettingsConsistentHashLBUseSourceIpFluent<A extends LoadBalancerSettingsConsistentHashLBUseSourceIpFluent<A>> extends BaseFluent<A>{
  public LoadBalancerSettingsConsistentHashLBUseSourceIpFluent() {
  }
  
  public LoadBalancerSettingsConsistentHashLBUseSourceIpFluent(LoadBalancerSettingsConsistentHashLBUseSourceIp instance) {
    this.copyInstance(instance);
  }
  private Boolean useSourceIp;
  
  protected void copyInstance(LoadBalancerSettingsConsistentHashLBUseSourceIp instance) {
    instance = (instance != null ? instance : new LoadBalancerSettingsConsistentHashLBUseSourceIp());
  
    if (instance != null) {
        this.withUseSourceIp(instance.getUseSourceIp());
        this.withUseSourceIp(instance.getUseSourceIp());
      }
  }
  
  public Boolean getUseSourceIp() {
    return this.useSourceIp;
  }
  
  public A withUseSourceIp(Boolean useSourceIp) {
    this.useSourceIp=useSourceIp; return (A) this;
  }
  
  public boolean hasUseSourceIp() {
    return this.useSourceIp != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    LoadBalancerSettingsConsistentHashLBUseSourceIpFluent that = (LoadBalancerSettingsConsistentHashLBUseSourceIpFluent) o;
    if (!java.util.Objects.equals(useSourceIp, that.useSourceIp)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(useSourceIp,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (useSourceIp != null) { sb.append("useSourceIp:"); sb.append(useSourceIp); }
    sb.append("}");
    return sb.toString();
  }
  
  public A withUseSourceIp() {
    return withUseSourceIp(true);
  }
  

}
